@@ -13,4 +13,12 @@ if [ -n "$(git status -s)" ]; then
 fi
 
 export RELEASE_TESTING=1
-perl Makefile.PL && make && make test && make distcheck && make dist
+
+perl Makefile.PL
+make
+
+make test
+PDL_OPT_SIMPLEX_SIMPLE_WORKERS=10 make test
+
+make distcheck
+make dist
